@@ -3,15 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0708';
+our $VERSION = '0.0800';
 
 use Moo;
 use strictures 2;
-
 use Math::Random::Discrete ();
-use MIDI::Simple ();
 use List::Util qw(min);
-
 use namespace::clean;
 
 use constant TICKS => 96;
@@ -188,6 +185,13 @@ sub motif {
     return $motif;
 }
 
+
+sub motifs {
+    my ($self, $n) = @_;
+    my @motifs = map { $self->motif } 1 .. $n;
+    return @motifs;
+}
+
 sub _duration {
     my ( $self, $name ) = @_;
 
@@ -217,7 +221,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0708
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -371,6 +375,12 @@ The default B<pool_select> used constructs this by selecting a B<pool>
 duration at random, that fits into the size remaining after each
 application, in a loop until the B<size> is met.
 
+=head2 motifs
+
+  @motifs = $mdp->motifs($n);
+
+Return B<n> motifs.
+
 =head1 SEE ALSO
 
 The F<eg/*> and F<t/01-methods.t> programs in this distribution.
@@ -389,7 +399,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Gene Boggs.
+This software is copyright (c) 2023 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
